[![PyPI - latest](https://img.shields.io/pypi/v/slimevr-tracker-emulator?label=latest&logo=pypi)](https://pypi.org/project/slimevr-tracker-emulator/)
[![PyPI - Python](https://img.shields.io/pypi/pyversions/slimevr-tracker-emulator?logo=pypi)](https://pypi.org/project/slimevr-tracker-emulator/)

# SlimeVR Tracker Emulator

Simple **async lib** for [SlimeVR](https://github.com/SlimeVR) tracker emulation

> See [srv.py](https://github.com/ameharoo/PythonSlimeVRTracker/blob/master/srv.py) for examples